Constant Field Values
Contents
org.mapsforge.*
-
org.mapsforge.map.rendertheme.renderinstruction.Caption Modifier and Type Constant Field Value public static final floatDEFAULT_GAP5.0f
-
org.mapsforge.map.scalebar.ImperialUnitAdapter Modifier and Type Constant Field Value public static final doubleMETER_FOOT_RATIO0.3048public static final intONE_MILE5280 -
org.mapsforge.map.scalebar.MetricUnitAdapter Modifier and Type Constant Field Value public static final intONE_KILOMETER1000 -
org.mapsforge.map.scalebar.NauticalUnitAdapter Modifier and Type Constant Field Value public static final intONE_MILE1852