public interface RenderCallback
| Modifier and Type | Method and Description |
|---|---|
void |
renderArea(RenderContext renderContext,
Paint fill,
Paint stroke,
int level,
PolylineContainer way)
Renders an area with the given parameters.
|
void |
renderAreaCaption(RenderContext renderContext,
Display display,
int priority,
String caption,
float horizontalOffset,
float verticalOffset,
Paint fill,
Paint stroke,
Position position,
int maxTextWidth,
PolylineContainer way)
Renders an area caption with the given text.
|
void |
renderAreaSymbol(RenderContext renderContext,
Display display,
int priority,
Bitmap symbol,
PolylineContainer way)
Renders an area symbol with the given bitmap.
|
void |
renderPointOfInterestCaption(RenderContext renderContext,
Display display,
int priority,
String caption,
float horizontalOffset,
float verticalOffset,
Paint fill,
Paint stroke,
Position position,
int maxTextWidth,
PointOfInterest poi)
Renders a point of interest caption with the given text.
|
void |
renderPointOfInterestCircle(RenderContext renderContext,
float radius,
Paint fill,
Paint stroke,
int level,
PointOfInterest poi)
Renders a point of interest circle with the given parameters.
|
void |
renderPointOfInterestSymbol(RenderContext renderContext,
Display display,
int priority,
Bitmap symbol,
PointOfInterest poi)
Renders a point of interest symbol with the given bitmap.
|
void |
renderWay(RenderContext renderContext,
Paint stroke,
float dy,
int level,
PolylineContainer way)
Renders a way with the given parameters.
|
void |
renderWaySymbol(RenderContext renderContext,
Display display,
int priority,
Bitmap symbol,
float dy,
boolean alignCenter,
boolean repeat,
float repeatGap,
float repeatStart,
boolean rotate,
PolylineContainer way)
Renders a way with the given symbol along the way path.
|
void |
renderWayText(RenderContext renderContext,
Display display,
int priority,
String text,
float dy,
Paint fill,
Paint stroke,
PolylineContainer way)
Renders a way with the given text along the way path.
|
void renderArea(RenderContext renderContext, Paint fill, Paint stroke, int level, PolylineContainer way)
renderContext - fill - the paint to be used for rendering the area.stroke - an optional paint for the area casing (may be null).level - void renderAreaCaption(RenderContext renderContext, Display display, int priority, String caption, float horizontalOffset, float verticalOffset, Paint fill, Paint stroke, Position position, int maxTextWidth, PolylineContainer way)
renderContext - display - display modepriority - priority levelcaption - the text.horizontalOffset - the horizontal offset of the text.verticalOffset - the vertical offset of the text.fill - the paint for the text.stroke - the casing of the text (may be null).position - optional position (may be null)maxTextWidth - maximum text width .way - the way for the caption.void renderAreaSymbol(RenderContext renderContext, Display display, int priority, Bitmap symbol, PolylineContainer way)
renderContext - symbol - void renderPointOfInterestCaption(RenderContext renderContext, Display display, int priority, String caption, float horizontalOffset, float verticalOffset, Paint fill, Paint stroke, Position position, int maxTextWidth, PointOfInterest poi)
renderContext - caption - the text to be rendered.horizontalOffset - the horizontal offset of the caption.verticalOffset - the vertical offset of the caption.fill - the paint to be used for rendering the text.stroke - an optional paint for the text casing (may be null).position - void renderPointOfInterestCircle(RenderContext renderContext, float radius, Paint fill, Paint stroke, int level, PointOfInterest poi)
renderContext - radius - the radius of the circle.fill - the paint to be used for rendering the circle.stroke - an optional paint for the circle casing (may be null).level - void renderPointOfInterestSymbol(RenderContext renderContext, Display display, int priority, Bitmap symbol, PointOfInterest poi)
renderContext - symbol - void renderWay(RenderContext renderContext, Paint stroke, float dy, int level, PolylineContainer way)
renderContext - stroke - the paint to be used for rendering the way.dy - the offset of the way.level - void renderWaySymbol(RenderContext renderContext, Display display, int priority, Bitmap symbol, float dy, boolean alignCenter, boolean repeat, float repeatGap, float repeatStart, boolean rotate, PolylineContainer way)
renderContext - symbol - the symbol to be rendered.dy - the offset of the way.alignCenter - true if the symbol should be centered, false otherwise.repeat - true if the symbol should be repeated, false otherwise.repeatGap - distance between repetitions.repeatStart - void renderWayText(RenderContext renderContext, Display display, int priority, String text, float dy, Paint fill, Paint stroke, PolylineContainer way)
renderContext - text - the text to be rendered.dy - the offset of the way text.fill - the paint to be used for rendering the text.stroke - Copyright © 2015 mapsforge.org