Package org.mapsforge.map.rendertheme
package org.mapsforge.map.rendertheme
-
ClassDescriptionAn ExternalRenderTheme allows for customizing the rendering style of the map via an XML file.Callback methods for rendering areas, ways and points of interest (POIs).A RenderContext contains all the information and data to render a map area, it is passed between calls in order to avoid local data stored in the DatabaseRenderer.A StreamRenderTheme allows for customizing the rendering style of the map via an XML input stream.Callback methods for render theme.Interface for a render theme which is defined in XML.Interface callbacks in Rendertheme V4+ to create a settings menu on the fly.Entry class for automatically building menus from rendertheme V4+ files.Interface for a provider of resources referenced inside XML themes.A ZipRenderTheme allows for customizing the rendering style of the map via an XML from an archive.Resource provider reading resource files out of a zip input stream.