public static enum MapScaleBar.ScaleBarPosition extends Enum<MapScaleBar.ScaleBarPosition>
| Enum Constant and Description |
|---|
BOTTOM_CENTER |
BOTTOM_LEFT |
BOTTOM_RIGHT |
TOP_CENTER |
TOP_LEFT |
TOP_RIGHT |
| Modifier and Type | Method and Description |
|---|---|
static MapScaleBar.ScaleBarPosition |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static MapScaleBar.ScaleBarPosition[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final MapScaleBar.ScaleBarPosition BOTTOM_CENTER
public static final MapScaleBar.ScaleBarPosition BOTTOM_LEFT
public static final MapScaleBar.ScaleBarPosition BOTTOM_RIGHT
public static final MapScaleBar.ScaleBarPosition TOP_CENTER
public static final MapScaleBar.ScaleBarPosition TOP_LEFT
public static final MapScaleBar.ScaleBarPosition TOP_RIGHT
public static MapScaleBar.ScaleBarPosition[] values()
for (MapScaleBar.ScaleBarPosition c : MapScaleBar.ScaleBarPosition.values()) System.out.println(c);
public static MapScaleBar.ScaleBarPosition valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant
with the specified nameNullPointerException - if the argument is nullCopyright © 2015 mapsforge.org