public class DisplayModel extends Observable
| Constructor and Description |
|---|
DisplayModel() |
| Modifier and Type | Method and Description |
|---|---|
int |
getBackgroundColor()
Returns the background color.
|
static float |
getDefaultUserScaleFactor()
Get the default scale factor for all newly created DisplayModels.
|
static float |
getDeviceScaleFactor()
Returns the device scale factor.
|
float |
getScaleFactor()
Returns the overall scale factor.
|
int |
getTileSize()
Width and height of a map tile in pixel after system and user scaling is applied.
|
float |
getUserScaleFactor()
Returns the user scale factor.
|
void |
setBackgroundColor(int color)
Set the background color.
|
static void |
setDefaultUserScaleFactor(float scaleFactor)
Set the default scale factor for all newly created DisplayModels, so can be used to apply user settings from a
device.
|
static void |
setDeviceScaleFactor(float scaleFactor)
Set the device scale factor.
|
void |
setFixedTileSize(int tileSize)
Forces the tile size to a fixed value
|
void |
setUserScaleFactor(float scaleFactor)
Set the user scale factor.
|
addObserver, notifyObservers, removeObserverpublic static float getDefaultUserScaleFactor()
public static float getDeviceScaleFactor()
public static void setDefaultUserScaleFactor(float scaleFactor)
scaleFactor - the default scale factor to be applied to all new DisplayModels.public static void setDeviceScaleFactor(float scaleFactor)
scaleFactor - the device scale factor.public int getBackgroundColor()
public float getScaleFactor()
public int getTileSize()
public float getUserScaleFactor()
public void setBackgroundColor(int color)
color - the color to use.public void setFixedTileSize(int tileSize)
tileSize - the fixed tile size to use if != 0, if 0 the tile size will be calculatedpublic void setUserScaleFactor(float scaleFactor)
scaleFactor - the user scale factor to use.Copyright © 2014 mapsforge.org