public interface RenderCallback
| Modifier and Type | Method and Description |
|---|---|
void |
renderArea(PolylineContainer way,
Paint fill,
Paint stroke,
int level)
Renders an area with the given parameters.
|
void |
renderAreaCaption(PolylineContainer way,
Display display,
int priority,
String caption,
float horizontalOffset,
float verticalOffset,
Paint fill,
Paint stroke,
Position position,
int maxTextWidth)
Renders an area caption with the given text.
|
void |
renderAreaSymbol(PolylineContainer way,
Display display,
int priority,
Bitmap symbol)
Renders an area symbol with the given bitmap.
|
void |
renderPointOfInterestCaption(PointOfInterest poi,
Display display,
int priority,
String caption,
float horizontalOffset,
float verticalOffset,
Paint fill,
Paint stroke,
Position position,
int maxTextWidth,
Tile tile)
Renders a point of interest caption with the given text.
|
void |
renderPointOfInterestCircle(PointOfInterest poi,
float radius,
Paint fill,
Paint stroke,
int level,
Tile tile)
Renders a point of interest circle with the given parameters.
|
void |
renderPointOfInterestSymbol(PointOfInterest poi,
Display display,
int priority,
Bitmap symbol,
Tile tile)
Renders a point of interest symbol with the given bitmap.
|
void |
renderWay(PolylineContainer way,
Paint stroke,
float dy,
int level)
Renders a way with the given parameters.
|
void |
renderWaySymbol(PolylineContainer way,
Display display,
int priority,
Bitmap symbol,
float dy,
boolean alignCenter,
boolean repeat,
float repeatGap,
float repeatStart,
boolean rotate)
Renders a way with the given symbol along the way path.
|
void |
renderWayText(PolylineContainer way,
Display display,
int priority,
String text,
float dy,
Paint fill,
Paint stroke)
Renders a way with the given text along the way path.
|
void renderArea(PolylineContainer way, Paint fill, Paint stroke, int level)
fill - the paint to be used for rendering the area.stroke - an optional paint for the area casing (may be null).level - the drawing level on which the area should be rendered.void renderAreaCaption(PolylineContainer way, Display display, int priority, String caption, float horizontalOffset, float verticalOffset, Paint fill, Paint stroke, Position position, int maxTextWidth)
way - the way for the caption.display - display modepriority - priority levelcaption - the text.horizontalOffset - the horizontal offset of the text.verticalOffset - the vertical offset of the text.fill - the paint for the text.stroke - the casing of the text (may be null).position - optional position (may be null)maxTextWidth - maximum text width .void renderAreaSymbol(PolylineContainer way, Display display, int priority, Bitmap symbol)
symbol - the symbol to be rendered.void renderPointOfInterestCaption(PointOfInterest poi, Display display, int priority, String caption, float horizontalOffset, float verticalOffset, Paint fill, Paint stroke, Position position, int maxTextWidth, Tile tile)
caption - the text to be rendered.horizontalOffset - the horizontal offset of the caption.verticalOffset - the vertical offset of the caption.fill - the paint to be used for rendering the text.stroke - an optional paint for the text casing (may be null).position - an optional position for the caption (may be null).void renderPointOfInterestCircle(PointOfInterest poi, float radius, Paint fill, Paint stroke, int level, Tile tile)
radius - the radius of the circle.fill - the paint to be used for rendering the circle.stroke - an optional paint for the circle casing (may be null).level - the drawing level on which the circle should be rendered.void renderPointOfInterestSymbol(PointOfInterest poi, Display display, int priority, Bitmap symbol, Tile tile)
symbol - the symbol to be rendered.void renderWay(PolylineContainer way, Paint stroke, float dy, int level)
stroke - the paint to be used for rendering the way.dy - the offset of the way.level - the drawing level on which the way should be rendered.void renderWaySymbol(PolylineContainer way, Display display, int priority, Bitmap symbol, float dy, boolean alignCenter, boolean repeat, float repeatGap, float repeatStart, boolean rotate)
symbol - the symbol to be rendered.dy - the offset of the way.alignCenter - true if the symbol should be centered, false otherwise.repeat - true if the symbol should be repeated, false otherwise.repeatGap - distance between repetitions.repeatStart - offset from start.void renderWayText(PolylineContainer way, Display display, int priority, String text, float dy, Paint fill, Paint stroke)
text - the text to be rendered.dy - the offset of the way text.fill - the paint to be used for rendering the text.stroke - an optional paint for the text casing (may be null).Copyright © 2014 mapsforge.org