public interface RenderCallback
| Modifier and Type | Method and Description |
|---|---|
void |
renderArea(Paint fill,
Paint stroke,
int level)
Renders an area with the given parameters.
|
void |
renderAreaCaption(String caption,
float verticalOffset,
Paint fill,
Paint stroke)
Renders an area caption with the given text.
|
void |
renderAreaSymbol(Bitmap symbol)
Renders an area symbol with the given bitmap.
|
void |
renderPointOfInterestCaption(String caption,
float verticalOffset,
Paint fill,
Paint stroke)
Renders a point of interest caption with the given text.
|
void |
renderPointOfInterestCircle(float radius,
Paint fill,
Paint stroke,
int level)
Renders a point of interest circle with the given parameters.
|
void |
renderPointOfInterestSymbol(Bitmap symbol)
Renders a point of interest symbol with the given bitmap.
|
void |
renderWay(Paint stroke,
int level)
Renders a way with the given parameters.
|
void |
renderWaySymbol(Bitmap symbol,
boolean alignCenter,
boolean repeat)
Renders a way with the given symbol along the way path.
|
void |
renderWayText(String text,
Paint fill,
Paint stroke)
Renders a way with the given text along the way path.
|
void renderArea(Paint fill, Paint stroke, int level)
fill - the paint to be used for rendering the area.stroke - an optional paint for the area casing (may be null).level - the drawing level on which the area should be rendered.void renderAreaCaption(String caption, float verticalOffset, Paint fill, Paint stroke)
caption - the text to be rendered.verticalOffset - the vertical offset of the caption.fill - the paint to be used for rendering the text.stroke - an optional paint for the text casing (may be null).void renderAreaSymbol(Bitmap symbol)
symbol - the symbol to be rendered.void renderPointOfInterestCaption(String caption, float verticalOffset, Paint fill, Paint stroke)
caption - the text to be rendered.verticalOffset - the vertical offset of the caption.fill - the paint to be used for rendering the text.stroke - an optional paint for the text casing (may be null).void renderPointOfInterestCircle(float radius,
Paint fill,
Paint stroke,
int level)
radius - the radius of the circle.fill - the paint to be used for rendering the circle.stroke - an optional paint for the circle casing (may be null).level - the drawing level on which the circle should be rendered.void renderPointOfInterestSymbol(Bitmap symbol)
symbol - the symbol to be rendered.void renderWay(Paint stroke, int level)
stroke - the paint to be used for rendering the way.level - the drawing level on which the way should be rendered.void renderWaySymbol(Bitmap symbol, boolean alignCenter, boolean repeat)
symbol - the symbol to be rendered.alignCenter - true if the symbol should be centered, false otherwise.repeat - true if the symbol should be repeated, false otherwise.Copyright © 2014 mapsforge.org