| Interface | Description |
|---|---|
| RenderCallback |
Callback methods for rendering areas, ways and points of interest (POIs).
|
| XmlRenderTheme |
Interface for a render theme which is defined in XML.
|
| Class | Description |
|---|---|
| ExternalRenderTheme |
An ExternalRenderTheme allows for customizing the rendering style of the map via an XML file.
|
| XmlUtils |
| Enum | Description |
|---|---|
| InternalRenderTheme |
Enumeration of all internal rendering themes.
|
Copyright © 2014 mapsforge.org